# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: blickfeld/config/named_scan_pattern.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .. import options_pb2 as blickfeld_dot_options__pb2
from ..config import scan_pattern_pb2 as blickfeld_dot_config_dot_scan__pattern__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='blickfeld/config/named_scan_pattern.proto',
  package='blickfeld.protocol.config',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n)blickfeld/config/named_scan_pattern.proto\x12\x19\x62lickfeld.protocol.config\x1a\x17\x62lickfeld/options.proto\x1a#blickfeld/config/scan_pattern.proto\"\xa3\x01\n\x10NamedScanPattern\x12=\n\x04name\x18\x01 \x01(\tB/\xaa\xb5\x18+[a-zA-Z0-9]([a-zA-Z0-9]|[_ \\-][a-zA-Z0-9])*\x12\x36\n\x06\x63onfig\x18\x02 \x01(\x0b\x32&.blickfeld.protocol.config.ScanPattern\x12\x18\n\tread_only\x18\x03 \x01(\x08:\x05\x66\x61lse'
  ,
  dependencies=[blickfeld_dot_options__pb2.DESCRIPTOR,blickfeld_dot_config_dot_scan__pattern__pb2.DESCRIPTOR,])




_NAMEDSCANPATTERN = _descriptor.Descriptor(
  name='NamedScanPattern',
  full_name='blickfeld.protocol.config.NamedScanPattern',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='blickfeld.protocol.config.NamedScanPattern.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\252\265\030+[a-zA-Z0-9]([a-zA-Z0-9]|[_ \\-][a-zA-Z0-9])*', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='config', full_name='blickfeld.protocol.config.NamedScanPattern.config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='read_only', full_name='blickfeld.protocol.config.NamedScanPattern.read_only', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=135,
  serialized_end=298,
)

_NAMEDSCANPATTERN.fields_by_name['config'].message_type = blickfeld_dot_config_dot_scan__pattern__pb2._SCANPATTERN
DESCRIPTOR.message_types_by_name['NamedScanPattern'] = _NAMEDSCANPATTERN
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

NamedScanPattern = _reflection.GeneratedProtocolMessageType('NamedScanPattern', (_message.Message,), {
  'DESCRIPTOR' : _NAMEDSCANPATTERN,
  '__module__' : 'blickfeld.config.named_scan_pattern_pb2'
  # @@protoc_insertion_point(class_scope:blickfeld.protocol.config.NamedScanPattern)
  })
_sym_db.RegisterMessage(NamedScanPattern)


_NAMEDSCANPATTERN.fields_by_name['name']._options = None
# @@protoc_insertion_point(module_scope)
