# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: blickfeld/status/server.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .. import options_pb2 as blickfeld_dot_options__pb2
from ..stream import connection_pb2 as blickfeld_dot_stream_dot_connection__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='blickfeld/status/server.proto',
  package='blickfeld.protocol.status',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1d\x62lickfeld/status/server.proto\x12\x19\x62lickfeld.protocol.status\x1a\x17\x62lickfeld/options.proto\x1a!blickfeld/stream/connection.proto\"\xdb\x04\n\x06Server\x12\x39\n\x07\x63lients\x18\x01 \x03(\x0b\x32(.blickfeld.protocol.status.Server.Client\x12\x45\n\rnetwork_stats\x18\x02 \x01(\x0b\x32..blickfeld.protocol.status.Server.NetworkStats\x1a\xab\x02\n\x0cNetworkStats\x12\x44\n\x04sent\x18\x01 \x01(\x0b\x32\x36.blickfeld.protocol.status.Server.NetworkStats.Channel\x12H\n\x08received\x18\x02 \x01(\x0b\x32\x36.blickfeld.protocol.status.Server.NetworkStats.Channel\x12\x1b\n\x10\x64ropped_messages\x18\x03 \x01(\x04:\x01\x30\x1an\n\x07\x43hannel\x12\x1b\n\x10total_byte_count\x18\x01 \x01(\x04:\x01\x30\x12\x1e\n\x10\x62ytes_per_second\x18\x02 \x01(\x02\x42\x04\xb0\xb5\x18\x01\x12&\n\x18maximum_bytes_per_second\x18\x03 \x01(\x02\x42\x04\xb0\xb5\x18\x01\x1a\xa0\x01\n\x06\x43lient\x12;\n\rsubscriptions\x18\x01 \x03(\x0b\x32$.blickfeld.protocol.stream.Subscribe\x12\x45\n\rnetwork_stats\x18\x02 \x01(\x0b\x32..blickfeld.protocol.status.Server.NetworkStats\x12\x12\n\nidentifier\x18\x03 \x01(\t'
  ,
  dependencies=[blickfeld_dot_options__pb2.DESCRIPTOR,blickfeld_dot_stream_dot_connection__pb2.DESCRIPTOR,])




_SERVER_NETWORKSTATS_CHANNEL = _descriptor.Descriptor(
  name='Channel',
  full_name='blickfeld.protocol.status.Server.NetworkStats.Channel',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='total_byte_count', full_name='blickfeld.protocol.status.Server.NetworkStats.Channel.total_byte_count', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bytes_per_second', full_name='blickfeld.protocol.status.Server.NetworkStats.Channel.bytes_per_second', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\260\265\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='maximum_bytes_per_second', full_name='blickfeld.protocol.status.Server.NetworkStats.Channel.maximum_bytes_per_second', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\260\265\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=451,
  serialized_end=561,
)

_SERVER_NETWORKSTATS = _descriptor.Descriptor(
  name='NetworkStats',
  full_name='blickfeld.protocol.status.Server.NetworkStats',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sent', full_name='blickfeld.protocol.status.Server.NetworkStats.sent', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='received', full_name='blickfeld.protocol.status.Server.NetworkStats.received', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dropped_messages', full_name='blickfeld.protocol.status.Server.NetworkStats.dropped_messages', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_SERVER_NETWORKSTATS_CHANNEL, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=262,
  serialized_end=561,
)

_SERVER_CLIENT = _descriptor.Descriptor(
  name='Client',
  full_name='blickfeld.protocol.status.Server.Client',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='subscriptions', full_name='blickfeld.protocol.status.Server.Client.subscriptions', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='network_stats', full_name='blickfeld.protocol.status.Server.Client.network_stats', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='identifier', full_name='blickfeld.protocol.status.Server.Client.identifier', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=564,
  serialized_end=724,
)

_SERVER = _descriptor.Descriptor(
  name='Server',
  full_name='blickfeld.protocol.status.Server',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='clients', full_name='blickfeld.protocol.status.Server.clients', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='network_stats', full_name='blickfeld.protocol.status.Server.network_stats', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_SERVER_NETWORKSTATS, _SERVER_CLIENT, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=121,
  serialized_end=724,
)

_SERVER_NETWORKSTATS_CHANNEL.containing_type = _SERVER_NETWORKSTATS
_SERVER_NETWORKSTATS.fields_by_name['sent'].message_type = _SERVER_NETWORKSTATS_CHANNEL
_SERVER_NETWORKSTATS.fields_by_name['received'].message_type = _SERVER_NETWORKSTATS_CHANNEL
_SERVER_NETWORKSTATS.containing_type = _SERVER
_SERVER_CLIENT.fields_by_name['subscriptions'].message_type = blickfeld_dot_stream_dot_connection__pb2._SUBSCRIBE
_SERVER_CLIENT.fields_by_name['network_stats'].message_type = _SERVER_NETWORKSTATS
_SERVER_CLIENT.containing_type = _SERVER
_SERVER.fields_by_name['clients'].message_type = _SERVER_CLIENT
_SERVER.fields_by_name['network_stats'].message_type = _SERVER_NETWORKSTATS
DESCRIPTOR.message_types_by_name['Server'] = _SERVER
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Server = _reflection.GeneratedProtocolMessageType('Server', (_message.Message,), {

  'NetworkStats' : _reflection.GeneratedProtocolMessageType('NetworkStats', (_message.Message,), {

    'Channel' : _reflection.GeneratedProtocolMessageType('Channel', (_message.Message,), {
      'DESCRIPTOR' : _SERVER_NETWORKSTATS_CHANNEL,
      '__module__' : 'blickfeld.status.server_pb2'
      # @@protoc_insertion_point(class_scope:blickfeld.protocol.status.Server.NetworkStats.Channel)
      })
    ,
    'DESCRIPTOR' : _SERVER_NETWORKSTATS,
    '__module__' : 'blickfeld.status.server_pb2'
    # @@protoc_insertion_point(class_scope:blickfeld.protocol.status.Server.NetworkStats)
    })
  ,

  'Client' : _reflection.GeneratedProtocolMessageType('Client', (_message.Message,), {
    'DESCRIPTOR' : _SERVER_CLIENT,
    '__module__' : 'blickfeld.status.server_pb2'
    # @@protoc_insertion_point(class_scope:blickfeld.protocol.status.Server.Client)
    })
  ,
  'DESCRIPTOR' : _SERVER,
  '__module__' : 'blickfeld.status.server_pb2'
  # @@protoc_insertion_point(class_scope:blickfeld.protocol.status.Server)
  })
_sym_db.RegisterMessage(Server)
_sym_db.RegisterMessage(Server.NetworkStats)
_sym_db.RegisterMessage(Server.NetworkStats.Channel)
_sym_db.RegisterMessage(Server.Client)


_SERVER_NETWORKSTATS_CHANNEL.fields_by_name['bytes_per_second']._options = None
_SERVER_NETWORKSTATS_CHANNEL.fields_by_name['maximum_bytes_per_second']._options = None
# @@protoc_insertion_point(module_scope)
