# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: blickfeld/config/algorithm.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .. import options_pb2 as blickfeld_dot_options__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='blickfeld/config/algorithm.proto',
  package='blickfeld.protocol.config',
  syntax='proto2',
  serialized_options=b'\370\001\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n blickfeld/config/algorithm.proto\x12\x19\x62lickfeld.protocol.config\x1a\x17\x62lickfeld/options.proto\"\xcf\x04\n\tAlgorithm\x12\\\n\x16\x62\x61\x63kground_subtraction\x18\x01 \x01(\x0b\x32:.blickfeld.protocol.config.Algorithm.BackgroundSubtractionH\x00\x12N\n\x0fneighbor_filter\x18\x02 \x01(\x0b\x32\x33.blickfeld.protocol.config.Algorithm.NeighborFilterH\x00\x12Z\n\x15static_transformation\x18\x03 \x01(\x0b\x32\x39.blickfeld.protocol.config.Algorithm.StaticTransformationH\x00\x1a\xb8\x01\n\x15\x42\x61\x63kgroundSubtraction\x12\x39\n\x15initialization_frames\x18\x01 \x01(\r:\x02\x31\x30\x42\x16\x81\xb5\x18\x00\x00\x00\x00\x00\x00\xf0?\x89\xb5\x18\x00\x00\x00\x00\x00\x00$@\x12>\n\x16\x65xponential_decay_rate\x18\x02 \x01(\x02:\x06\x30.0025B\x16\x81\xb5\x18\x00\x00\x00\x00\x00\x00\x00\x00\x89\xb5\x18\x00\x00\x00\x00\x00\x00\xf0?J\x04\x08\x03\x10\x04J\x04\x08\x04\x10\x05R\x18\x63lassification_threshold\x1a\x10\n\x0eNeighborFilter\x1a\x63\n\x14StaticTransformation\x12#\n\x0frotation_matrix\x18\x01 \x03(\x02\x42\n\x10\x01\xa0\xb5\x18\x12\xb0\xb5\x18\x01\x12&\n\x12translation_vector\x18\x02 \x03(\x02\x42\n\x10\x01\xa0\xb5\x18\x06\xb0\xb5\x18\x01\x42\x06\n\x04\x61lgoB\x03\xf8\x01\x01'
  ,
  dependencies=[blickfeld_dot_options__pb2.DESCRIPTOR,])




_ALGORITHM_BACKGROUNDSUBTRACTION = _descriptor.Descriptor(
  name='BackgroundSubtraction',
  full_name='blickfeld.protocol.config.Algorithm.BackgroundSubtraction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='initialization_frames', full_name='blickfeld.protocol.config.Algorithm.BackgroundSubtraction.initialization_frames', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=10,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\201\265\030\000\000\000\000\000\000\360?\211\265\030\000\000\000\000\000\000$@', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exponential_decay_rate', full_name='blickfeld.protocol.config.Algorithm.BackgroundSubtraction.exponential_decay_rate', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(0.0025),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\201\265\030\000\000\000\000\000\000\000\000\211\265\030\000\000\000\000\000\000\360?', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=369,
  serialized_end=553,
)

_ALGORITHM_NEIGHBORFILTER = _descriptor.Descriptor(
  name='NeighborFilter',
  full_name='blickfeld.protocol.config.Algorithm.NeighborFilter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=555,
  serialized_end=571,
)

_ALGORITHM_STATICTRANSFORMATION = _descriptor.Descriptor(
  name='StaticTransformation',
  full_name='blickfeld.protocol.config.Algorithm.StaticTransformation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='rotation_matrix', full_name='blickfeld.protocol.config.Algorithm.StaticTransformation.rotation_matrix', index=0,
      number=1, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\020\001\240\265\030\022\260\265\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='translation_vector', full_name='blickfeld.protocol.config.Algorithm.StaticTransformation.translation_vector', index=1,
      number=2, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\020\001\240\265\030\006\260\265\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=573,
  serialized_end=672,
)

_ALGORITHM = _descriptor.Descriptor(
  name='Algorithm',
  full_name='blickfeld.protocol.config.Algorithm',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='background_subtraction', full_name='blickfeld.protocol.config.Algorithm.background_subtraction', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='neighbor_filter', full_name='blickfeld.protocol.config.Algorithm.neighbor_filter', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='static_transformation', full_name='blickfeld.protocol.config.Algorithm.static_transformation', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_ALGORITHM_BACKGROUNDSUBTRACTION, _ALGORITHM_NEIGHBORFILTER, _ALGORITHM_STATICTRANSFORMATION, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='algo', full_name='blickfeld.protocol.config.Algorithm.algo',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=89,
  serialized_end=680,
)

_ALGORITHM_BACKGROUNDSUBTRACTION.containing_type = _ALGORITHM
_ALGORITHM_NEIGHBORFILTER.containing_type = _ALGORITHM
_ALGORITHM_STATICTRANSFORMATION.containing_type = _ALGORITHM
_ALGORITHM.fields_by_name['background_subtraction'].message_type = _ALGORITHM_BACKGROUNDSUBTRACTION
_ALGORITHM.fields_by_name['neighbor_filter'].message_type = _ALGORITHM_NEIGHBORFILTER
_ALGORITHM.fields_by_name['static_transformation'].message_type = _ALGORITHM_STATICTRANSFORMATION
_ALGORITHM.oneofs_by_name['algo'].fields.append(
  _ALGORITHM.fields_by_name['background_subtraction'])
_ALGORITHM.fields_by_name['background_subtraction'].containing_oneof = _ALGORITHM.oneofs_by_name['algo']
_ALGORITHM.oneofs_by_name['algo'].fields.append(
  _ALGORITHM.fields_by_name['neighbor_filter'])
_ALGORITHM.fields_by_name['neighbor_filter'].containing_oneof = _ALGORITHM.oneofs_by_name['algo']
_ALGORITHM.oneofs_by_name['algo'].fields.append(
  _ALGORITHM.fields_by_name['static_transformation'])
_ALGORITHM.fields_by_name['static_transformation'].containing_oneof = _ALGORITHM.oneofs_by_name['algo']
DESCRIPTOR.message_types_by_name['Algorithm'] = _ALGORITHM
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Algorithm = _reflection.GeneratedProtocolMessageType('Algorithm', (_message.Message,), {

  'BackgroundSubtraction' : _reflection.GeneratedProtocolMessageType('BackgroundSubtraction', (_message.Message,), {
    'DESCRIPTOR' : _ALGORITHM_BACKGROUNDSUBTRACTION,
    '__module__' : 'blickfeld.config.algorithm_pb2'
    # @@protoc_insertion_point(class_scope:blickfeld.protocol.config.Algorithm.BackgroundSubtraction)
    })
  ,

  'NeighborFilter' : _reflection.GeneratedProtocolMessageType('NeighborFilter', (_message.Message,), {
    'DESCRIPTOR' : _ALGORITHM_NEIGHBORFILTER,
    '__module__' : 'blickfeld.config.algorithm_pb2'
    # @@protoc_insertion_point(class_scope:blickfeld.protocol.config.Algorithm.NeighborFilter)
    })
  ,

  'StaticTransformation' : _reflection.GeneratedProtocolMessageType('StaticTransformation', (_message.Message,), {
    'DESCRIPTOR' : _ALGORITHM_STATICTRANSFORMATION,
    '__module__' : 'blickfeld.config.algorithm_pb2'
    # @@protoc_insertion_point(class_scope:blickfeld.protocol.config.Algorithm.StaticTransformation)
    })
  ,
  'DESCRIPTOR' : _ALGORITHM,
  '__module__' : 'blickfeld.config.algorithm_pb2'
  # @@protoc_insertion_point(class_scope:blickfeld.protocol.config.Algorithm)
  })
_sym_db.RegisterMessage(Algorithm)
_sym_db.RegisterMessage(Algorithm.BackgroundSubtraction)
_sym_db.RegisterMessage(Algorithm.NeighborFilter)
_sym_db.RegisterMessage(Algorithm.StaticTransformation)


DESCRIPTOR._options = None
_ALGORITHM_BACKGROUNDSUBTRACTION.fields_by_name['initialization_frames']._options = None
_ALGORITHM_BACKGROUNDSUBTRACTION.fields_by_name['exponential_decay_rate']._options = None
_ALGORITHM_STATICTRANSFORMATION.fields_by_name['rotation_matrix']._options = None
_ALGORITHM_STATICTRANSFORMATION.fields_by_name['translation_vector']._options = None
# @@protoc_insertion_point(module_scope)
