# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: blickfeld/status/main.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .. import options_pb2 as blickfeld_dot_options__pb2
from ..status import scanner_pb2 as blickfeld_dot_status_dot_scanner__pb2
from ..status import temperature_pb2 as blickfeld_dot_status_dot_temperature__pb2
from ..status import server_pb2 as blickfeld_dot_status_dot_server__pb2
from ..status import time_synchronization_pb2 as blickfeld_dot_status_dot_time__synchronization__pb2
from ..status import imu_pb2 as blickfeld_dot_status_dot_imu__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='blickfeld/status/main.proto',
  package='blickfeld.protocol',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1b\x62lickfeld/status/main.proto\x12\x12\x62lickfeld.protocol\x1a\x17\x62lickfeld/options.proto\x1a\x1e\x62lickfeld/status/scanner.proto\x1a\"blickfeld/status/temperature.proto\x1a\x1d\x62lickfeld/status/server.proto\x1a+blickfeld/status/time_synchronization.proto\x1a\x1a\x62lickfeld/status/imu.proto\"\xc7\x02\n\x06Status\x12\x33\n\x07scanner\x18\x01 \x01(\x0b\x32\".blickfeld.protocol.status.Scanner\x12<\n\x0ctemperatures\x18\x02 \x03(\x0b\x32&.blickfeld.protocol.status.Temperature\x12\x31\n\x06server\x18\x05 \x01(\x0b\x32!.blickfeld.protocol.status.Server\x12\x31\n\x03imu\x18\x07 \x01(\x0b\x32\x1e.blickfeld.protocol.status.IMUB\x04\xb0\xb5\x18\x01\x12R\n\x14time_synchronization\x18\x08 \x01(\x0b\x32..blickfeld.protocol.status.TimeSynchronizationB\x04\xb0\xb5\x18\x01*\x04\x08\x03\x10\x04*\x04\x08\x04\x10\x05*\x04\x08\x06\x10\x07'
  ,
  dependencies=[blickfeld_dot_options__pb2.DESCRIPTOR,blickfeld_dot_status_dot_scanner__pb2.DESCRIPTOR,blickfeld_dot_status_dot_temperature__pb2.DESCRIPTOR,blickfeld_dot_status_dot_server__pb2.DESCRIPTOR,blickfeld_dot_status_dot_time__synchronization__pb2.DESCRIPTOR,blickfeld_dot_status_dot_imu__pb2.DESCRIPTOR,])




_STATUS = _descriptor.Descriptor(
  name='Status',
  full_name='blickfeld.protocol.Status',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='scanner', full_name='blickfeld.protocol.Status.scanner', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='temperatures', full_name='blickfeld.protocol.Status.temperatures', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='server', full_name='blickfeld.protocol.Status.server', index=2,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='imu', full_name='blickfeld.protocol.Status.imu', index=3,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\260\265\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_synchronization', full_name='blickfeld.protocol.Status.time_synchronization', index=4,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\260\265\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=True,
  syntax='proto2',
  extension_ranges=[(3, 4), (4, 5), (6, 7), ],
  oneofs=[
  ],
  serialized_start=249,
  serialized_end=576,
)

_STATUS.fields_by_name['scanner'].message_type = blickfeld_dot_status_dot_scanner__pb2._SCANNER
_STATUS.fields_by_name['temperatures'].message_type = blickfeld_dot_status_dot_temperature__pb2._TEMPERATURE
_STATUS.fields_by_name['server'].message_type = blickfeld_dot_status_dot_server__pb2._SERVER
_STATUS.fields_by_name['imu'].message_type = blickfeld_dot_status_dot_imu__pb2._IMU
_STATUS.fields_by_name['time_synchronization'].message_type = blickfeld_dot_status_dot_time__synchronization__pb2._TIMESYNCHRONIZATION
DESCRIPTOR.message_types_by_name['Status'] = _STATUS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Status = _reflection.GeneratedProtocolMessageType('Status', (_message.Message,), {
  'DESCRIPTOR' : _STATUS,
  '__module__' : 'blickfeld.status.main_pb2'
  # @@protoc_insertion_point(class_scope:blickfeld.protocol.Status)
  })
_sym_db.RegisterMessage(Status)


_STATUS.fields_by_name['imu']._options = None
_STATUS.fields_by_name['time_synchronization']._options = None
# @@protoc_insertion_point(module_scope)
